# Params3

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**job_id** | **str** | Name of the CI sending the vote.  |
**commit_hash** | **str** | commit_hash of tested repo.  |
**distro_hash** | **str** | distro_hash of tested repo.  |
**extended_hash** | **str** | extended_hash of tested repo.  |
**url** | **str** | URL where to find additional information from the CI execution.  |
**timestamp** | **int** | Timestamp (in seconds since the epoch)  |
**success** | **bool** | Was the CI execution successful?  |
**notes** | **bool** | Additional notes  | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


